/*
    KSysGuard, the KDE System Guard
	   
    Copyright (c) 1999 - 2001 Chris Schlaeger <cs@kde.org>
    
    This program is free software; you can redistribute it and/or
    modify it under the terms of version 2 of the GNU General Public
    License as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: lmsensors.h,v 1.3 2002/04/15 05:41:39 tokoe Exp $
*/

#ifndef _lmsensors_h_
#define _lmsensors_h_

void initLmSensors(struct SensorModul* sm);
void exitLmSensors(void);

void printLmSensor(const char* cmd);
void printLmSensorInfo(const char* cmd);

#endif
